@@ -746,7 +746,7 @@ tkgrid(commarb, sticky="w")
 
 ## export directory
 dirFrame <- ttklabelframe(tab6, text=gettextRcmdr("Storage Directory"))
-dirVar <- tclVar(.stored.designfac$dirVar)
+putRcmdr("dirVar", tclVar(.stored.designfac$dirVar))
 dirEntry <- tkentry(dirFrame, width="50", textvariable=dirVar)
 dirButton <- buttonRcmdr(dirFrame, text = gettextRcmdr("Change directory"), 
         foreground = "darkgreen", width = "20", command = onChangeDir, 
